@@ -65,6 +65,8 @@ void wait_for_hook_initialization(void)
 	}
 }
 
+void init_hook_files(void);
+
 bool obs_module_load(void)
 {
 	struct win_version_info ver;
@@ -94,6 +96,7 @@ bool obs_module_load(void)
 
 	char *config_path = obs_module_config_path(NULL);
 
+	init_hook_files();
 	init_hooks_thread =
 		CreateThread(NULL, 0, init_hooks, config_path, 0, NULL);
 	obs_register_source(&game_capture_info);
